@@ -19,6 +19,21 @@
 #include <Python.h>
 #include <errno.h>
 
+/* choose the appropriate stat and fstat functions and return structs */
+/* This code taken from Python's posixmodule.c */
+#undef STAT
+#if defined(MS_WIN64) || defined(MS_WIN32)
+#	define STAT _stati64
+#	define FSTAT _fstati64
+#	define STRUCT_STAT struct _stati64
+#else
+#	define STAT stat
+#	define FSTAT fstat
+#	define STRUCT_STAT struct stat
+#endif
+
+extern int lstat(const char *, struct stat *);
+
 static PyObject *UnknownFileTypeError;
 static PyObject *c_make_file_dict(PyObject *self, PyObject *args);
 static PyObject *long2str(PyObject *self, PyObject *args);
@@ -35,13 +50,19 @@ static PyObject *c_make_file_dict(self, args)
   char *filename, filetype[5];
   struct stat sbuf;
   long int mode, perms;
+  int res;
 
   if (!PyArg_ParseTuple(args, "s", &filename)) return NULL;
-  if (lstat(filename, &sbuf) != 0) {
+
+  Py_BEGIN_ALLOW_THREADS
+  res = lstat(filename, &sbuf);
+  Py_END_ALLOW_THREADS
+
+  if (res != 0) {
 	if (errno == ENOENT || errno == ENOTDIR)
 	  return Py_BuildValue("{s:s}", "type", NULL);
 	else {
-	  PyErr_SetFromErrno(PyExc_OSError);
+	  PyErr_SetFromErrnoWithFilename(PyExc_OSError, filename);
 	  return NULL;
 	}
   }
