@@ -72,13 +72,17 @@ class Restore:
 		base_incs = Restore.get_inclist(Globals.rbdir.append("increments"))
 		if not base_incs: return old_rest_time
 		inctimes = [Time.stringtotime(inc.getinctime()) for inc in base_incs]
-		return max(filter(lambda time: time <= old_rest_time,
-						  inctimes + [mirror_time]))
+		inctimes.append(mirror_time)
+		older_times = filter(lambda time: time <= old_rest_time, inctimes)
+		if older_times: return max(older_times)
+		else: # restore time older than oldest increment, just return that
+			return min(inctimes)
 
 	def get_inclist(inc_rpath):
 		"""Returns increments with given base"""
 		dirname, basename = inc_rpath.dirsplit()
 		parent_dir = RPath(inc_rpath.conn, dirname, ())
+		if not parent_dir.isdir(): return [] # inc directory not created yet
 		index = inc_rpath.index
 
 		if index:
